#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ctypes as ct

def ptr_property(obj, attr, doc=None):
    def getv(self):
        o = getattr(self, obj)
        return getattr(o.contents, attr)

    def setv(self, value):
        o = getattr(self, obj)
        setattr(o.contents, attr, value)

    return property(getv, setv, doc=doc)


class Array(object):
    """
    List of objects based on C array.

    This is used to pass data between Python space and C based array.
    """
    def __init__(self, array, data_attr, size_attr):
        """
        Create instance of the list.
        """
        self._array = array
        self._size_attr = size_attr
        self._data_attr = data_attr


    def __getitem__(self, i):
        data = getattr(self._array.contents, self._data_attr)
        return data[i]


    def __len__(self):
        return getattr(self._array.contents, self._size_attr)


    def __iter__(self):
        data = getattr(self._array.contents, self._data_attr)
        for i in range(0, len(self)):
            yield data[i]

# vim: sw=4:et:ai
