#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Unit test for the libdeco and DecoMecha errors raising.
"""

from decomecha import DecoEngine

import unittest

class ErrorTestCase(unittest.TestCase):
    """
    Test error raising.
    """
    def test_no_feature_error(self):
        """
        Test no feature profile dive error
        """
        deco = DecoEngine()
        deco.add_segment(45, 25)
        self.assertRaises(ValueError, deco.add_segment, 25, 15)


    def test_profile_max_depth(self):
        """
        Test if error is raised for invalid depth
        """
        deco = DecoEngine()
        self.assertRaises(ValueError, deco.add_segment, 131, 15)


    def test_profile_max_gas_number(self):
        """
        Test if error is raised when maximum number of gases reached
        """
        deco = DecoEngine()
        deco.add_gas(0, 21)
        deco.add_gas(22, 50)
        deco.add_gas(15, 65)
        deco.add_gas(10, 80)
        deco.add_gas(6, 100)
        self.assertRaises(ValueError, deco.add_gas, 1, 15)


    def test_profile_max_setpoint_num(self):
        """
        Test if error is raised when maximum number of setpoints reached
        """
        deco = DecoEngine()
        deco.add_setpoint(0, 1.1)
        self.assertRaises(ValueError, deco.add_setpoint, 7, 1.2)


class OSTCCrashTestCase(unittest.TestCase):
    """
    OSTC crash test.
    """
    def test_multi_depth(self):
        """
        Test deco calculation for depths 10, 20, ... 80
        
        This resulted in assertion error in firmware 2.0.
        """
        deco = DecoEngine()
        deco.gf_low = 20
        deco.gf_high = 90
        deco.add_segment(10, 20)
        for k in range(1, 9):
            deco.profile[0].depth = k * 10
            info = deco.calculate()

# vim: sw=4:et:ai
