#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Parameters changes unit tests.
"""

from decomecha import DecoEngine

import unittest
        
class ParamTestCase(unittest.TestCase):
    """
    Parameters changes unit tests.
    """
    def test_altitude(self):
        """
        Test altitude change
        """
        d = DecoEngine()
        d.altitude = 700
        self.assertEquals(931, d.pressure)


    def test_pressure(self):
        """
        Test pressure change
        """
        d = DecoEngine()
        d.pressure = 901
        self.assertEquals(901, d.pressure)


    def test_setpoint_add(self):
        """
        Test adding a setpoint
        """
        d = DecoEngine()
        d.add_setpoint(0, 1.4)

        self.assertEquals(1, len(d.setpoints))
        self.assertEquals(0, d.setpoints[0].depth)
        self.assertEquals(1.4, round(d.setpoints[0].ppO2, 2))


    def test_gas_list_reset(self):
        """
        Test if gas is at start of a dive
        """
        d1 = DecoEngine()
        d1.add_segment(45, 25)
        d1.add_gas(0, 21)
        d1.add_gas(22, 50)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(45, 25)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        s1 = i1.stops[5]
        s2 = i2.stops[5]

        # if stops times are the same, then the gas mixes are not reset on
        # C level
        self.assertFalse(s1.time == s2.time)


# vim: sw=4:et:ai
